import { CfnStage } from "@aws-cdk/aws-apigateway";
import { BaseComplianceChecker } from "./compliance-checker";
export interface ApiGatewayConfig {
    logging?: boolean;
    ssl?: boolean;
    xray?: boolean;
    cacheDataEncrypted?: boolean;
}
export declare class ApiGatewayComplianceChecker extends BaseComplianceChecker<CfnStage> {
    constructor(config: ApiGatewayConfig);
    checkCompliance(node: CfnStage): void;
    /**
     * [APIGateway.1] API Gateway REST and WebSocket API logging should be enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-apigateway-1
     */
    private checkAPILogging;
    /**
     * [APIGateway.2] API Gateway REST API stages should be configured to use SSL certificates for backend authentication
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-apigateway-2
     */
    private checkSSL;
    /**
     * [APIGateway.3] API Gateway REST API stages should have AWS X-Ray tracing enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-apigateway-3
     */
    private checkXRay;
    /**
     * [APIGateway.5] API Gateway REST API cache data should be encrypted at rest
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-apigateway-5
     */
    private checkCacheEncrypted;
}
