"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AutoScalingGroupComplianceChecker = void 0;
const core_1 = require("@aws-cdk/core");
const compliance_checker_1 = require("./compliance-checker");
class AutoScalingGroupComplianceChecker extends compliance_checker_1.BaseComplianceChecker {
    constructor(config) {
        super({ autoScalingGroup: config });
    }
    checkCompliance(node) {
        var _a, _b;
        if ((_b = (_a = this.config.autoScalingGroup) === null || _a === void 0 ? void 0 : _a.loadBalancerHealthCheck) !== null && _b !== void 0 ? _b : true) {
            this.checkLoadBalancerHealthCheck(node);
        }
    }
    /**
     * [AutoScaling.1] Auto Scaling groups associated with a load balancer should use load balancer health checks
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-autoscaling-1
     */
    checkLoadBalancerHealthCheck(node) {
        var _a, _b;
        if ((_b = (_a = node.loadBalancerNames) === null || _a === void 0 ? void 0 : _a.length) !== null && _b !== void 0 ? _b : 0 > 0) {
            if (!node.healthCheckType || !node.healthCheckGracePeriod) {
                core_1.Annotations.of(node).addError("[AutoScaling.1] Auto Scaling groups associated with a load balancer should use load balancer health checks");
            }
        }
    }
}
exports.AutoScalingGroupComplianceChecker = AutoScalingGroupComplianceChecker;
