"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _AWSFoundationalSecurityBestPracticesChecker_ApiGatewayComplianceChecker, _AWSFoundationalSecurityBestPracticesChecker_AutoScalingGroupComplianceChecker, _AWSFoundationalSecurityBestPracticesChecker_DynamoDBComplianceChecker, _AWSFoundationalSecurityBestPracticesChecker_IAMPolicyComplianceChecker, _AWSFoundationalSecurityBestPracticesChecker_LambdaComplianceChecker, _AWSFoundationalSecurityBestPracticesChecker_RDSComplianceChecker;
Object.defineProperty(exports, "__esModule", { value: true });
exports.AWSFoundationalSecurityBestPracticesChecker = void 0;
const aws_apigateway_1 = require("@aws-cdk/aws-apigateway");
const aws_iam_1 = require("@aws-cdk/aws-iam");
const aws_lambda_1 = require("@aws-cdk/aws-lambda");
const aws_rds_1 = require("@aws-cdk/aws-rds");
const aws_dynamodb_1 = require("@aws-cdk/aws-dynamodb");
const aws_autoscaling_1 = require("@aws-cdk/aws-autoscaling");
const api_gateway_checker_1 = require("./api-gateway-checker");
const auto_scaling_group_checker_1 = require("./auto-scaling-group-checker");
const dynamo_db_checker_1 = require("./dynamo-db-checker");
const iam_policy_checker_1 = require("./iam-policy-checker");
const lambda_checker_1 = require("./lambda-checker");
const rds_compliance_checker_1 = require("./rds-compliance-checker");
/**
 * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html
 */
class AWSFoundationalSecurityBestPracticesChecker {
    /**
     * Initialise a new Checker. All values in the configuration default to true if not provided.
     * @param config
     */
    constructor(config = {
        apigateway: {
            logging: true,
            ssl: true,
            xray: true,
            cacheDataEncrypted: true,
        },
        autoScalingGroup: {
            loadBalancerHealthCheck: true,
        },
        iam: { fullAdmin: true, wildcardServiceActions: true },
        lambda: { supportedRuntimes: true },
        rds: {
            publicAccess: true,
            storageEncrypted: true,
            multiAz: true,
            enhancedMonitoring: true,
            deletionProtection: true,
            logExports: true,
            iamAuth: true,
            autoMinorVersionUpgrades: true,
            copyTagsToSnapshot: true,
        },
        dynamodb: { autoScaling: true, pointInTimeRecovery: true },
    }) {
        _AWSFoundationalSecurityBestPracticesChecker_ApiGatewayComplianceChecker.set(this, void 0);
        _AWSFoundationalSecurityBestPracticesChecker_AutoScalingGroupComplianceChecker.set(this, void 0);
        _AWSFoundationalSecurityBestPracticesChecker_DynamoDBComplianceChecker.set(this, void 0);
        _AWSFoundationalSecurityBestPracticesChecker_IAMPolicyComplianceChecker.set(this, void 0);
        _AWSFoundationalSecurityBestPracticesChecker_LambdaComplianceChecker.set(this, void 0);
        _AWSFoundationalSecurityBestPracticesChecker_RDSComplianceChecker.set(this, void 0);
        __classPrivateFieldSet(this, _AWSFoundationalSecurityBestPracticesChecker_ApiGatewayComplianceChecker, new api_gateway_checker_1.ApiGatewayComplianceChecker(config.apigateway), "f");
        __classPrivateFieldSet(this, _AWSFoundationalSecurityBestPracticesChecker_AutoScalingGroupComplianceChecker, new auto_scaling_group_checker_1.AutoScalingGroupComplianceChecker(config.autoScalingGroup), "f");
        __classPrivateFieldSet(this, _AWSFoundationalSecurityBestPracticesChecker_DynamoDBComplianceChecker, new dynamo_db_checker_1.DynamoDBComplianceChecker(config.dynamodb), "f");
        __classPrivateFieldSet(this, _AWSFoundationalSecurityBestPracticesChecker_IAMPolicyComplianceChecker, new iam_policy_checker_1.IAMPolicyComplianceChecker(config.iam), "f");
        __classPrivateFieldSet(this, _AWSFoundationalSecurityBestPracticesChecker_LambdaComplianceChecker, new lambda_checker_1.LambdaComplianceChecker(config.lambda), "f");
        __classPrivateFieldSet(this, _AWSFoundationalSecurityBestPracticesChecker_RDSComplianceChecker, new rds_compliance_checker_1.RDSComplianceChecker(config.rds), "f");
    }
    visit(node) {
        if (node instanceof aws_apigateway_1.CfnStage) {
            __classPrivateFieldGet(this, _AWSFoundationalSecurityBestPracticesChecker_ApiGatewayComplianceChecker, "f").checkCompliance(node);
        }
        else if (node instanceof aws_autoscaling_1.CfnAutoScalingGroup) {
            __classPrivateFieldGet(this, _AWSFoundationalSecurityBestPracticesChecker_AutoScalingGroupComplianceChecker, "f").checkCompliance(node);
        }
        else if (node instanceof aws_dynamodb_1.CfnTable) {
            __classPrivateFieldGet(this, _AWSFoundationalSecurityBestPracticesChecker_DynamoDBComplianceChecker, "f").checkCompliance(node);
        }
        else if (node instanceof aws_iam_1.CfnPolicy) {
            __classPrivateFieldGet(this, _AWSFoundationalSecurityBestPracticesChecker_IAMPolicyComplianceChecker, "f").checkCompliance(node);
        }
        else if (node instanceof aws_lambda_1.CfnFunction) {
            __classPrivateFieldGet(this, _AWSFoundationalSecurityBestPracticesChecker_LambdaComplianceChecker, "f").checkCompliance(node);
        }
        else if (node instanceof aws_rds_1.CfnDBInstance || node instanceof aws_rds_1.CfnDBCluster) {
            __classPrivateFieldGet(this, _AWSFoundationalSecurityBestPracticesChecker_RDSComplianceChecker, "f").checkCompliance(node);
        }
    }
}
exports.AWSFoundationalSecurityBestPracticesChecker = AWSFoundationalSecurityBestPracticesChecker;
_AWSFoundationalSecurityBestPracticesChecker_ApiGatewayComplianceChecker = new WeakMap(), _AWSFoundationalSecurityBestPracticesChecker_AutoScalingGroupComplianceChecker = new WeakMap(), _AWSFoundationalSecurityBestPracticesChecker_DynamoDBComplianceChecker = new WeakMap(), _AWSFoundationalSecurityBestPracticesChecker_IAMPolicyComplianceChecker = new WeakMap(), _AWSFoundationalSecurityBestPracticesChecker_LambdaComplianceChecker = new WeakMap(), _AWSFoundationalSecurityBestPracticesChecker_RDSComplianceChecker = new WeakMap();
