import { CfnPolicy } from "@aws-cdk/aws-iam";
import { BaseComplianceChecker } from "./compliance-checker";
export interface IAMConfig {
    fullAdmin?: boolean;
    wildcardServiceActions?: boolean;
}
export declare class IAMPolicyComplianceChecker extends BaseComplianceChecker<CfnPolicy> {
    constructor(config: IAMConfig);
    checkCompliance(node: CfnPolicy): void;
    /**
     * [IAM.1] IAM policies should not allow full "*" administrative privileges.
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-iam-1
     */
    private checkIAMPolicyFullAdmin;
    /**
     * [IAM.21] IAM customer managed policies that you create should not allow wildcard actions for services
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-iam-21
     */
    private checkIAMPolicyServiceWildcards;
}
