"use strict";
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _LambdaComplianceChecker_supportedLambdaRuntimes;
Object.defineProperty(exports, "__esModule", { value: true });
exports.LambdaComplianceChecker = exports.LambdaConfig = void 0;
const aws_lambda_1 = require("@aws-cdk/aws-lambda");
const core_1 = require("@aws-cdk/core");
const compliance_checker_1 = require("./compliance-checker");
class LambdaConfig {
}
exports.LambdaConfig = LambdaConfig;
class LambdaComplianceChecker extends compliance_checker_1.BaseComplianceChecker {
    constructor(config) {
        super({ lambda: config });
        _LambdaComplianceChecker_supportedLambdaRuntimes.set(this, [
            aws_lambda_1.Runtime.NODEJS_14_X,
            aws_lambda_1.Runtime.NODEJS_12_X,
            aws_lambda_1.Runtime.NODEJS_10_X,
            aws_lambda_1.Runtime.PYTHON_3_8,
            aws_lambda_1.Runtime.PYTHON_3_7,
            aws_lambda_1.Runtime.PYTHON_3_6,
            aws_lambda_1.Runtime.RUBY_2_7,
            aws_lambda_1.Runtime.RUBY_2_5,
            aws_lambda_1.Runtime.JAVA_11,
            aws_lambda_1.Runtime.JAVA_8,
            aws_lambda_1.Runtime.JAVA_8_CORRETTO,
            aws_lambda_1.Runtime.GO_1_X,
            aws_lambda_1.Runtime.DOTNET_CORE_3_1,
            aws_lambda_1.Runtime.DOTNET_CORE_2_1,
        ]);
    }
    checkCompliance(node) {
        var _a, _b;
        if ((_b = (_a = this.config.lambda) === null || _a === void 0 ? void 0 : _a.supportedRuntimes) !== null && _b !== void 0 ? _b : true) {
            this.checkLambdaSupportedRuntime(node);
        }
    }
    /**
     * [Lambda.2] Lambda functions should use supported runtimes
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-lambda-2
     */
    checkLambdaSupportedRuntime(node) {
        if (!__classPrivateFieldGet(this, _LambdaComplianceChecker_supportedLambdaRuntimes, "f").some((r) => r.name === node.runtime)) {
            core_1.Annotations.of(node).addError("[Lambda.2] Lambda functions should use supported runtimes");
        }
    }
}
exports.LambdaComplianceChecker = LambdaComplianceChecker;
_LambdaComplianceChecker_supportedLambdaRuntimes = new WeakMap();
