"use strict";
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _RDSComplianceChecker_instances, _RDSComplianceChecker_getDescriptor;
Object.defineProperty(exports, "__esModule", { value: true });
exports.RDSComplianceChecker = void 0;
const aws_rds_1 = require("@aws-cdk/aws-rds");
const core_1 = require("@aws-cdk/core");
const compliance_checker_1 = require("./compliance-checker");
class RDSComplianceChecker extends compliance_checker_1.BaseComplianceChecker {
    constructor(config) {
        super({ rds: config });
        _RDSComplianceChecker_instances.add(this);
    }
    checkCompliance(node) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t;
        if ((_b = (_a = this.config.rds) === null || _a === void 0 ? void 0 : _a.publicAccess) !== null && _b !== void 0 ? _b : true) {
            this.checkRDSPublicAccess(node);
        }
        if ((_d = (_c = this.config.rds) === null || _c === void 0 ? void 0 : _c.storageEncrypted) !== null && _d !== void 0 ? _d : true) {
            this.checkRDSEncryption(node);
        }
        if ((_f = (_e = this.config.rds) === null || _e === void 0 ? void 0 : _e.multiAz) !== null && _f !== void 0 ? _f : true) {
            this.checkMultipleAZs(node);
        }
        if ((_h = (_g = this.config.rds) === null || _g === void 0 ? void 0 : _g.enhancedMonitoring) !== null && _h !== void 0 ? _h : true) {
            this.checkEnhancedMonitoring(node);
        }
        if ((_k = (_j = this.config.rds) === null || _j === void 0 ? void 0 : _j.deletionProtection) !== null && _k !== void 0 ? _k : true) {
            this.checkDeletionProtection(node);
        }
        if ((_m = (_l = this.config.rds) === null || _l === void 0 ? void 0 : _l.logExports) !== null && _m !== void 0 ? _m : true) {
            this.checkLogExports(node);
        }
        if ((_p = (_o = this.config.rds) === null || _o === void 0 ? void 0 : _o.iamAuth) !== null && _p !== void 0 ? _p : true) {
            this.checkIAMAuthentication(node);
        }
        if ((_r = (_q = this.config.rds) === null || _q === void 0 ? void 0 : _q.autoMinorVersionUpgrades) !== null && _r !== void 0 ? _r : true) {
            this.checkMinorVersionUpgrades(node);
        }
        if ((_t = (_s = this.config.rds) === null || _s === void 0 ? void 0 : _s.copyTagsToSnapshot) !== null && _t !== void 0 ? _t : true) {
            this.checkCopyTagsToSnapshot(node);
        }
    }
    /**
     * [RDS.2] RDS DB instances should prohibit public access, determined by the PubliclyAccessible configuration
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-2
     */
    checkRDSPublicAccess(node) {
        // This check is only applicable to DB Instances.
        if (node instanceof aws_rds_1.CfnDBInstance && node.publiclyAccessible) {
            // Undefined is the same as false in this context, so we don't need to check or raise an error.
            core_1.Annotations.of(node).addError("[RDS.2] RDS DB instances should prohibit public access, determined by the PubliclyAccessible configuration");
        }
    }
    /**
     * [RDS.3] RDS DB instances should have encryption at rest enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-3
     */
    checkRDSEncryption(node) {
        // This check is only applicable to instances, not clusters.
        if (node instanceof aws_rds_1.CfnDBInstance &&
            node.dbClusterIdentifier === undefined &&
            !node.storageEncrypted) {
            core_1.Annotations.of(node).addError(`[RDS.3] RDS DB ${__classPrivateFieldGet(this, _RDSComplianceChecker_instances, "m", _RDSComplianceChecker_getDescriptor).call(this, node)} should have encryption at rest enabled`);
        }
    }
    /**
     * [RDS.5] RDS DB instances should be configured with multiple Availability Zones
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-5
     */
    checkMultipleAZs(node) {
        // This check is only applicable to instances, not clusters.
        if (node instanceof aws_rds_1.CfnDBInstance &&
            node.dbClusterIdentifier === undefined &&
            !node.multiAz) {
            core_1.Annotations.of(node).addError(`[RDS.5] RDS DB ${__classPrivateFieldGet(this, _RDSComplianceChecker_instances, "m", _RDSComplianceChecker_getDescriptor).call(this, node)} should be configured with multiple Availability Zones`);
        }
    }
    /**
     * [RDS.6] Enhanced monitoring should be configured for RDS DB instances and clusters
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-6
     */
    checkEnhancedMonitoring(node) {
        if (node instanceof aws_rds_1.CfnDBInstance &&
            (!node.monitoringInterval || node.monitoringInterval < 1)) {
            // Each instance in a cluster requires enhanced monitoring.
            core_1.Annotations.of(node).addError("[RDS.6] Enhanced monitoring should be configured for RDS DB instances and clusters");
        }
    }
    /**
     * [RDS.8] RDS DB instances should have deletion protection enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-8
     */
    checkDeletionProtection(node) {
        if (node instanceof aws_rds_1.CfnDBCluster && !node.deletionProtection) {
            core_1.Annotations.of(node).addError(`[RDS.8] RDS DB ${__classPrivateFieldGet(this, _RDSComplianceChecker_instances, "m", _RDSComplianceChecker_getDescriptor).call(this, node)} should have deletion protection enabled`);
        }
        else if (node instanceof aws_rds_1.CfnDBInstance &&
            node.dbClusterIdentifier === undefined &&
            !node.deletionProtection) {
            core_1.Annotations.of(node).addError(`[RDS.8] RDS DB ${__classPrivateFieldGet(this, _RDSComplianceChecker_instances, "m", _RDSComplianceChecker_getDescriptor).call(this, node)} should have deletion protection enabled`);
        }
    }
    /**
     * [RDS.9] Database logging should be enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-9
     */
    checkLogExports(node) {
        if (node instanceof aws_rds_1.CfnDBCluster ||
            (node instanceof aws_rds_1.CfnDBInstance && node.dbClusterIdentifier === undefined)) {
            if (node.enableCloudwatchLogsExports === undefined ||
                node.enableCloudwatchLogsExports.length === 0) {
                core_1.Annotations.of(node).addError("[RDS.9] Database logging should be enabled");
            }
            else {
                // Check that the log types are valid.
                let expectedLogTypes = [];
                switch (node.engine) {
                    case "mysql":
                    case "aurora":
                    case "aurora-mysql":
                    case "mariadb":
                        expectedLogTypes = ["audit", "error", "general", "slowquery"];
                        break;
                    case "oracle-ee":
                    case "oracle-se2":
                        expectedLogTypes = ["alert", "audit", "trace", "listener"];
                        break;
                    case "postgres":
                    case "aurora-postgres":
                        expectedLogTypes = ["postgresql", "upgrade"];
                        break;
                    case "sqlserver-ee":
                    case "sqlserver-ex":
                    case "sqlserver-se":
                    case "sqlserver-web":
                        expectedLogTypes = ["error", "agent"];
                        break;
                    default:
                        expectedLogTypes = ["invalid"];
                        break;
                }
                if (!node.enableCloudwatchLogsExports.every((log) => expectedLogTypes.includes(log))) {
                    core_1.Annotations.of(node).addError("[RDS.9] Database logging should be enabled");
                }
            }
        }
    }
    /**
     * [RDS.10] IAM authentication should be configured for RDS instances & [RDS.12] IAM authentication should be configured for RDS clusters
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-10 & https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-12
     */
    checkIAMAuthentication(node) {
        if (node instanceof aws_rds_1.CfnDBInstance &&
            node.dbClusterIdentifier === undefined &&
            !node.enableIamDatabaseAuthentication) {
            core_1.Annotations.of(node).addError("[RDS.10] IAM authentication should be configured for RDS instances");
        }
        else if (node instanceof aws_rds_1.CfnDBCluster &&
            !node.enableIamDatabaseAuthentication) {
            core_1.Annotations.of(node).addError("[RDS.12] IAM authentication should be configured for RDS clusters");
        }
    }
    /**
     * [RDS.13] RDS automatic minor version upgrades should be enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-13
     */
    checkMinorVersionUpgrades(node) {
        if (node instanceof aws_rds_1.CfnDBInstance && !node.autoMinorVersionUpgrade) {
            core_1.Annotations.of(node).addError("[RDS.13] RDS automatic minor version upgrades should be enabled");
        }
    }
    /**
     * [RDS.16] RDS DB clusters should be configured to copy tags to snapshots & [RDS.17] RDS DB instances should be configured to copy tags to snapshots
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-16 & https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-rds-17
     */
    checkCopyTagsToSnapshot(node) {
        if (!node.copyTagsToSnapshot) {
            if (node instanceof aws_rds_1.CfnDBCluster) {
                core_1.Annotations.of(node).addWarning("[RDS.16] RDS DB clusters should be configured to copy tags to snapshots");
            }
            else if (node instanceof aws_rds_1.CfnDBInstance &&
                node.dbClusterIdentifier === undefined) {
                core_1.Annotations.of(node).addWarning("[RDS.17] RDS DB instances should be configured to copy tags to snapshots");
            }
        }
    }
}
exports.RDSComplianceChecker = RDSComplianceChecker;
_RDSComplianceChecker_instances = new WeakSet(), _RDSComplianceChecker_getDescriptor = function _RDSComplianceChecker_getDescriptor(node) {
    return node instanceof aws_rds_1.CfnDBInstance ? "instances" : "cluster";
};
